<?php
/** Scots (Scots)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author (vinny)
 * @author Avicennasis
 * @author Derek Ross
 * @author Malafaya
 * @author OchAyeTheNoo
 * @author Omnipaedista
 * @author Purodha
 * @author Shirayuki
 * @author The Evil IP address
 * @author Urhixidur
 * @author Ushanka
 * @author sco.wikipedia.org editors
 * @author לערי ריינהארט
 */

$messages = array(
# User preference toggles
'tog-underline'               => 'Unnerline airtins:',
'tog-highlightbroken'         => 'Format brucken airtins <a href="" class="new">like this</a> (alternative: like this<a href="" class="internal">?</a>).',
'tog-justify'                 => 'Justifee paragraphs',
'tog-hideminor'               => 'Hide smaa edits in recent chynges',
'tog-hidepatrolled'           => 'Hide patrolled edits in recent chynges',
'tog-newpageshidepatrolled'   => 'Hide patrolled pages frae the new page list',
'tog-extendwatchlist'         => 'Mak watchleet bigger tae shaw aw chynges',
'tog-usenewrc'                => 'Enhanced recent chynges (no for aa brousers)',
'tog-numberheadings'          => 'Auto-nummer heidins',
'tog-showtoolbar'             => 'Shaw edit toolbar',
'tog-editondblclick'          => 'Edit pages on dooble-dab (JavaScript)',
'tog-editsection'             => 'Enable section editin via [edit] airtins',
'tog-editsectiononrightclick' => 'Enable section editin bi richt-dabbin on section teitles (JavaScript)',
'tog-showtoc'                 => 'Shaw table o contents (for pages wi mair nor 3 heidins)',
'tog-rememberpassword'        => 'Mynd password ower sessions (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations'          => 'Add pages ye mak tar yer watchleet',
'tog-watchdefault'            => 'Add pages ye edit tae yer watchleet',
'tog-watchmoves'              => 'Eik pages A move tae ma watchleet',
'tog-watchdeletion'           => 'Eik pages A get rid o tae ma watchleet',
'tog-minordefault'            => 'Mairk aa edits "smaa" bi defaut',
'tog-previewontop'            => 'Shaw scance afore edit box an no efter it',
'tog-previewonfirst'          => 'Shaw scance on first edit',
'tog-nocache'                 => 'Disable page cachin',
'tog-enotifwatchlistpages'    => 'Send me an email on page chynges',
'tog-enotifusertalkpages'     => 'Send me an email whan ma uiser collogue page is chynged',
'tog-enotifminoredits'        => 'Send me an email for smaa edits o pages an aa',
'tog-enotifrevealaddr'        => 'Shaw ma email address in notification mails',
'tog-shownumberswatching'     => 'Shaw the nummer o watching uisers',
'tog-fancysig'                => 'Raw seignaturs (athoot automatic airtin)',
'tog-externaleditor'          => 'Uise external editor bi defaut',
'tog-externaldiff'            => 'Uise external diff bi defaut',
'tog-showjumplinks'           => 'Enable "loup til" accessibility airtins',
'tog-uselivepreview'          => 'Uise leeve preview (JavaScript) (Prattik)',
'tog-forceeditsummary'        => 'Gie me a jottin when A dinnae put in a edit summary',
'tog-watchlisthideown'        => 'Hide yer ain edits frae yer watchleet',
'tog-watchlisthidebots'       => 'Hide bot edits frae yer watchleet',
'tog-watchlisthideminor'      => 'Dinna shaw sma edits on ma watchleet',
'tog-watchlisthideliu'        => 'Hide edits by loggit in uisers frae the watchleet',
'tog-watchlisthideanons'      => 'Hide edits by nameless uisers frae the watchleet',
'tog-watchlisthidepatrolled'  => 'Hide patrolled edits frae the watchlist',
'tog-ccmeonemails'            => 'Gie me copies o emails A write tae ither uisers',
'tog-diffonly'                => 'Dinna shaw page contents ablo diffs',
'tog-showhiddencats'          => 'Shaw hidden categories',
'tog-norollbackdiff'          => 'Lave oot diff efter rowin back',

'underline-always'  => 'Aye',
'underline-never'   => 'Niver',
'underline-default' => 'Brouser defaut',

# Font style option in Special:Preferences
'editfont-sansserif' => 'Sans-serif font',
'editfont-serif'     => 'Serif font',

# Dates
'sunday'        => 'Sunday',
'monday'        => 'Monanday',
'tuesday'       => 'Tysday',
'wednesday'     => 'Wadensday',
'thursday'      => 'Fuirsday',
'friday'        => 'Friday',
'saturday'      => 'Seturday',
'sun'           => 'Sun',
'mon'           => 'Mon',
'tue'           => 'Tue',
'wed'           => 'Wed',
'thu'           => 'Thu',
'fri'           => 'Fri',
'sat'           => 'Sat',
'january'       => 'Januar',
'february'      => 'Februar',
'march'         => 'Mairch',
'april'         => 'Apryle',
'may_long'      => 'Mey',
'june'          => 'Juin',
'july'          => 'Julie',
'august'        => 'August',
'september'     => 'September',
'october'       => 'October',
'november'      => 'November',
'december'      => 'December',
'january-gen'   => 'Januar',
'february-gen'  => 'February',
'march-gen'     => 'March',
'april-gen'     => 'Apryle',
'may-gen'       => 'May',
'june-gen'      => 'Juin',
'july-gen'      => 'Julie',
'august-gen'    => 'August',
'september-gen' => 'September',
'october-gen'   => 'October',
'november-gen'  => 'November',
'december-gen'  => 'Dizember',
'jan'           => 'Jan',
'feb'           => 'Feb',
'mar'           => 'Mai',
'apr'           => 'Apr',
'may'           => 'Mey',
'jun'           => 'Jui',
'jul'           => 'Jul',
'aug'           => 'Aug',
'sep'           => 'Sep',
'oct'           => 'Oct',
'nov'           => 'Nov',
'dec'           => 'Diz',

# Categories related messages
'pagecategories'                 => '{{PLURAL:$1|Category|Categories}}',
'category_header'                => 'Pages in category "$1"',
'subcategories'                  => 'Subcategories',
'category-media-header'          => 'Eetems in category "$1"',
'category-empty'                 => "''This category haes no pages or eetems at the meenit.''",
'hidden-categories'              => '{{PLURAL:$1|Hidden categorie|Hidden categories}}',
'category-subcat-count'          => '{{PLURAL:$2|This category juist haes the follaein subcategory.|This category haes the follaein {{PLURAL:$1|subcategory|$1 subcategories}}, oot o $2 awthegither.}}',
'category-subcat-count-limited'  => 'This category haes the follaein {{PLURAL:$1|subcategory|$1 subcategories}}.',
'category-article-count'         => '{{PLURAL:$2|This category contains the ae follaein page.|The follaein {{PLURAL:$1|page|$1 pages}} is in this category, oot o $2 total.}}',
'category-article-count-limited' => 'The follaein {{PLURAL:$1|page|$1 pages}} is in this category.',
'category-file-count'            => '{{PLURAL:$2|This category hauds juist the ae follaein file.|The follaein {{PLURAL:$1|file|$1 files}}s is in this category, oot o $2 total.}}',
'category-file-count-limited'    => 'The follaein {{PLURAL:$1|file is|$1 files is}} in this category.',
'listingcontinuesabbrev'         => 'cont.',
'noindex-category'               => 'Noindexed pages',

'about'         => 'Aboot',
'article'       => 'Content page',
'newwindow'     => '(opens in new windae)',
'cancel'        => 'Cancel',
'moredotdotdot' => 'Mair...',
'mypage'        => 'Ma page',
'mytalk'        => 'Ma collogue',
'anontalk'      => 'Collogue for this IP',
'navigation'    => 'Navigation',
'and'           => '&#32;an',

# Cologne Blue skin
'qbfind'         => 'Rake',
'qbbrowse'       => 'Brouse',
'qbedit'         => 'Edit',
'qbpageoptions'  => 'This page',
'qbpageinfo'     => 'Context',
'qbmyoptions'    => 'Ma pages',
'qbspecialpages' => 'Byordinar pages',
'faq'            => 'ASQ',
'faqpage'        => 'Project:ASQ',

# Vector skin
'vector-action-addsection' => 'Add topic',
'vector-action-delete'     => 'Delete',
'vector-action-move'       => 'Flit',
'vector-action-protect'    => 'Fend',
'vector-view-create'       => 'Mak',
'vector-view-edit'         => 'Edit',
'vector-view-history'      => 'See history',
'vector-view-view'         => 'Read',
'vector-view-viewsource'   => 'View soorce',
'actions'                  => 'Actions',
'namespaces'               => 'Namespaces',
'variants'                 => 'Variants',

'errorpagetitle'    => 'Error',
'returnto'          => 'Return tae $1.',
'tagline'           => 'Frae {{SITENAME}}',
'help'              => 'Help',
'search'            => 'Rake',
'searchbutton'      => 'Rake',
'go'                => 'Gang',
'searcharticle'     => 'Gang',
'history'           => 'Page history',
'history_short'     => 'History',
'updatedmarker'     => 'chynged sin ma hindermast visit',
'printableversion'  => 'Prent version',
'permalink'         => 'Permanent airtin',
'print'             => 'Prent',
'edit'              => 'Edit',
'create'            => 'Mak',
'editthispage'      => 'Edit this page',
'create-this-page'  => 'Mak this page',
'delete'            => 'Delete',
'deletethispage'    => 'Delete this page',
'undelete_short'    => 'Undelete {{PLURAL:$1|ane edit|$1 edits}}',
'protect'           => 'Fend',
'protect_change'    => 'chynge',
'protectthispage'   => 'Fend this page',
'unprotect'         => 'Loose fend',
'unprotectthispage' => 'Loose the fend for this page',
'newpage'           => 'New page',
'talkpage'          => 'Blether ower this page',
'talkpagelinktext'  => 'Collogue',
'specialpage'       => 'Byordinar Page',
'personaltools'     => 'Personal tuils',
'postcomment'       => 'Eik a message',
'articlepage'       => 'Leuk at content page',
'talk'              => 'Collogue',
'views'             => 'Views',
'toolbox'           => 'Tuilkist',
'userpage'          => 'View uiser page',
'projectpage'       => 'View project page',
'imagepage'         => 'look ower image page',
'mediawikipage'     => 'View message page',
'templatepage'      => 'View template page',
'viewhelppage'      => 'View help page',
'categorypage'      => 'Scance category page',
'viewtalkpage'      => 'Scance ower collogue',
'otherlanguages'    => 'In ither leids',
'redirectedfrom'    => '(Reguidit frae $1)',
'redirectpagesub'   => 'Redirect page',
'lastmodifiedat'    => 'This page wis hindermaist chynged $2, $1.',
'viewcount'         => 'This page haes been accesst $1 {{PLURAL:$1|once|$1 times}}.',
'protectedpage'     => 'Protectit page',
'jumpto'            => 'Lowp tae:',
'jumptonavigation'  => 'navigation',
'jumptosearch'      => 'rake',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Aboot {{SITENAME}}',
'aboutpage'            => 'Project:Aboot',
'copyright'            => 'Aa text is available unner $1',
'copyrightpage'        => '{{ns:project}}:Copyrichts',
'currentevents'        => 'Gaun on the nou',
'currentevents-url'    => 'Project:Gaun on the nou',
'disclaimers'          => 'Disclamation',
'disclaimerpage'       => 'Project:General_disclamation',
'edithelp'             => 'Editin help',
'edithelppage'         => 'Help:Editin',
'helppage'             => 'Help:Contents',
'mainpage'             => 'Main Page',
'mainpage-description' => 'Main Page',
'policy-url'           => 'Project:Policy',
'portal'               => 'Commonty yett',
'portal-url'           => 'Project:Commonty Yett',
'privacy'              => 'Privacy policy',
'privacypage'          => 'Project:Privacy policy',

'badaccess'        => 'Permeission mishanter',
'badaccess-group0' => 'WARNIN: Ye arnae alloued tae dae whit you hae requestit!',
'badaccess-groups' => 'The action ye hae requestit is limitit tae uisers in {{PLURAL:$2|the group|ane o the groups}}: $1.',

'versionrequired'     => 'Version $1 of MediaWiki requirit',
'versionrequiredtext' => 'Version $1 o MediaWiki is requirit tae uise this page. Tak a keek at the [[Special:Version|version page]].',

'ok'                      => 'Okay',
'retrievedfrom'           => 'Taen frae "$1"',
'youhavenewmessages'      => 'Ye hae $1 ($2).',
'newmessageslink'         => 'new messages',
'newmessagesdifflink'     => 'diff wi last-but-ane reveision',
'youhavenewmessagesmulti' => 'Ye hae neow messages on $1',
'editsection'             => 'edit',
'editold'                 => 'edit',
'viewsourceold'           => 'ken soorce',
'editlink'                => 'edit',
'viewsourcelink'          => 'Scance ower the source',
'editsectionhint'         => 'Edit section: $1',
'toc'                     => 'Table o contents',
'showtoc'                 => 'shaw',
'hidetoc'                 => 'scouk',
'thisisdeleted'           => 'View or cower $1?',
'viewdeleted'             => 'View $1?',
'restorelink'             => '{{PLURAL:$1|one delete edit|$1 delete edits}}',
'feedlinks'               => 'Feed:',
'feed-invalid'            => "This feeds subscrieve's teep isnae habile.",
'feed-unavailable'        => 'Syndication feeds isna available',
'site-rss-feed'           => '$1 RSS Feed',
'site-atom-feed'          => '$1 Atom Feed',
'page-rss-feed'           => '"$1" RSS Feed',
'page-atom-feed'          => '"$1" Atom Feed',
'red-link-title'          => '$1 (page disna exist)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Page',
'nstab-user'      => 'Uiser page',
'nstab-media'     => 'Eetem page',
'nstab-special'   => 'Byordinar page',
'nstab-project'   => 'Project page',
'nstab-image'     => 'Eimage',
'nstab-mediawiki' => 'Message',
'nstab-template'  => 'Template',
'nstab-help'      => 'Help page',
'nstab-category'  => 'Category',

# Main script and global functions
'nosuchaction'      => 'Nae sic action',
'nosuchactiontext'  => "The action specifiee'd bi the URL isna recognised
Ye micht hae mistyped the URL, or follaed a wrang link
This micht forby be caused by a bug in the saftware uised by {{SITENAME}}.",
'nosuchspecialpage' => 'Nae sic byordinar page',
'nospecialpagetext' => '<strong>Ye hae requestit an invalid byordinar page.</strong>

A leet o valid byordinar pages can be funnd at [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error'                => 'Error',
'databaseerror'        => 'Database error',
'dberrortext'          => 'A database query syntax error haes occurt. This micht indicate a bug in the saftware. The last attemptit database query wis: <blockquote><tt>$1</tt></blockquote> frae athin function "<tt>$2</tt>". Database returned error "<tt>$3: $4</tt>".',
'dberrortextcl'        => 'A database query syntax error haes occurt. The last attemptit database query wis: "$1" frae athin function "$2". Database returned error "$3: $4".',
'laggedslavemode'      => 'Warning: Page micht nae contain recent updates',
'readonly'             => 'Database lockit',
'enterlockreason'      => "Enter a raeson for the lock, includin an estimate o whan the lock'll be lowsed",
'readonlytext'         => "The databae is lockit tae new entries an ither modifeecations the nou,
likely for routine database maintenance; efter that it'll be back tae normal.
The adminstration that lockit it gied this explanation:
$1",
'missing-article'      => 'The database didna find the text o a page that it shuid hae fund, cawed "$1" $2.

Maistly this is caused by follaein an ootdated diff or history link tae a page that haes been delete.

If this isna the case, you micht hae fund a bug in the saftware.
Please lat an [[Special:ListUsers/sysop|administrator]] ken aboot this, makin note o the URL.',
'missingarticle-rev'   => '(revision#: $1)',
'missingarticle-diff'  => '(Diff: $1, $2)',
'readonly_lag'         => 'The database haes been autaematically lockit while the sclave database servers catch up tae the maister',
'internalerror'        => 'Internal mishanter',
'internalerror_info'   => 'Internal error: $1',
'filecopyerror'        => 'Cuidna copy file "$1" tae "$2".',
'filerenameerror'      => 'Cuidna rename file "$1" tae "$2".',
'filedeleteerror'      => 'Cuidna delete file "$1".',
'directorycreateerror' => 'Culdnae mak directory "$1".',
'filenotfound'         => 'Cuidna fin file "$1".',
'fileexistserror'      => 'Culdnae write tae file "$1": file is already here',
'unexpected'           => 'Vailyie isnae expectit: "$1"="$2".',
'formerror'            => 'Error: cuidna submit form',
'badarticleerror'      => 'This action canna be duin tae this page.',
'cannotdelete'         => "Cuidna delete the page or eimage specifee'd. (It micht hae aareadies been delete bi some ither bodie.)",
'badtitle'             => 'Bad teitle',
'badtitletext'         => 'The requestit page teitle wis invalid, tuim, or a wranglie airtit inter-leid or inter-wiki teitle. It mibbe haes ane or mair chairacters that canna be uised in teitles.',
'perfcached'           => 'The follaeing data is cached an michtna be richt up tae date. A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
'perfcachedts'         => 'The followin data is cached, an wis hindermaist chynged $1. A maximum of {{PLURAL:$4|one result is|$4 results are}} available in the cache.',
'querypage-no-updates' => 'Updates for this page ar disablit at the meenit. Data here wilnae be refreshit at the meenit.',
'wrong_wfQuery_params' => 'Wrang parameters tae wfQuery()<br />
Exerce: $1<br />
Aks: $2',
'viewsource'           => 'View soorce',
'actionthrottled'      => 'Action devalit',
'actionthrottledtext'  => 'As an anti-spam meisur, ye ar limitit frae daein this action ower mony times in a ower short tid, an ye hae exceedit this limit. Please try again in a wee.',
'protectedpagetext'    => "Sairy, this page haes been '''lockit''' tae hinder vandalism.",
'viewsourcetext'       => 'Ye can leuk at an copy the soorce o this page:',
'protectedinterface'   => 'Sairy, but this page provides interface text for the saftware, an is lockit to hinder abuise.',
'editinginterface'     => "'''Warning:''' You are editing a page which is used to provide interface text for the software.
Changes to this page will affect the appearance of the user interface for other users.
For translations, please consider using [//translatewiki.net/wiki/Main_Page?setlang=en translatewiki.net], the MediaWiki localisation project.",
'sqlhidden'            => '(SQL query hidden)',
'cascadeprotected'     => 'This page haes been protectit fra editin, acause it is includit in the followin {{PLURAL:$1|page|pages}}, that are protectit wi the "cascading" option turnit on:
$2',
'namespaceprotected'   => "Ye dinna hae permeession tae edit pages in the '''$1''' namespace.",
'ns-specialprotected'  => 'Byordinar pages canna be editit.',
'titleprotected'       => "This teetle haes been protectit frae bein makkit by [[User:$1|$1]].
The grunds for this are: ''$2''.",

# Login and logout pages
'logouttext'                 => "'''Ye'r nou loggit oot.'''

Ye can continue to uise {{SITENAME}} namelessly, or ye can log in again as the same or as a different uiser.
Mynd that some pages micht continue tae be displayed as if ye war aye loggit in, till ye clear yer brouser cache.",
'welcomecreation'            => '== Guid tae see ye, $1! ==

Yer accoont haes been creatit.
Mynd an chynge yer [[Special:Preferences|{{SITENAME}} preferences]].',
'yourname'                   => 'Yer uiser name',
'yourpassword'               => 'Passwaird:',
'yourpasswordagain'          => 'Retype passwaird:',
'remembermypassword'         => 'Mynd ma password oan this browser (for a maximum of $1 {{PLURAL:$1|day|days}})',
'yourdomainname'             => 'Yer domain:',
'externaldberror'            => "Aither the wis an external authenteication database mishanter, or ye'r no alloued tae update yer external accoont.",
'login'                      => 'Log in',
'nav-login-createaccount'    => 'Log in / mak an accoont',
'loginprompt'                => 'Ye maun hae cookies enabled tae log in tae {{SITENAME}}.',
'userlogin'                  => 'Mak an accoont or log in',
'logout'                     => 'Log oot',
'userlogout'                 => 'Log oot',
'notloggedin'                => 'No loggit in',
'nologin'                    => "Dinna hae an accoont? '''$1'''.",
'nologinlink'                => 'Mak an accoont',
'createaccount'              => 'Mak new accoont',
'gotaccount'                 => "Got an accoont afore? '''$1'''.",
'gotaccountlink'             => 'Log in',
'userlogin-resetlink'        => 'Forgotten yer login details?',
'createaccountmail'          => 'bi email',
'badretype'                  => 'The passwords ye entered disna match.',
'userexists'                 => 'The uiser name ye entered is in uiss. Please chuise a different name.',
'loginerror'                 => 'Login mishanter',
'nocookiesnew'               => "The uiser accoont wis creatit, but ye'r no loggit in. {{SITENAME}} uises cookies tae log uisers in. Ye hae cookies disabled. Please enable them, than log in wi yer new uisername and password.",
'nocookieslogin'             => '{{SITENAME}} uises cookies tae log in uisers. Ye hae cookies disabled. Please enable thaim an gie it anither shot.',
'noname'                     => "Ye hivna specifee'd a valid uisername.",
'loginsuccesstitle'          => 'Login fine',
'loginsuccess'               => 'Ye\'re nou loggit in tae {{SITENAME}} as "$1".',
'nosuchuser'                 => 'The\'r nae sic uiser as "$1".
Uiser names are case-sensitive.
Check yer spellin, or uise [[Special:UserLogin/signup|mak a new accoont]].',
'nosuchusershort'            => 'The\'r nae sic uiser as "$1". Check yer spellin.',
'nouserspecified'            => 'Ye hae tae merk up a uisername.',
'wrongpassword'              => 'The password ye entered is wrang. Please gie it anither shot.',
'wrongpasswordempty'         => 'The password ye entered is blank. Please gie it anither shot.',
'passwordtooshort'           => 'Yer password is ower short.
It maun hae at laest $1 characters.',
'mailmypassword'             => 'E-mail new passwaird',
'passwordremindertitle'      => 'Password reminder frae {{SITENAME}}',
'passwordremindertext'       => 'Somebodie (maist likely you, frae IP address $1)
requestit that we send ye a new {{SITENAME}} login password ($4).
The password for uiser "$2" is nou "$3".
Ye shuid log in an chynge yer password richt awa.

Gin some ither bodie made this request or gin ye\'v myndit o yer password an
ye dinna want tae chynge it onie mair, ye can ignore this message an cairrie on uisin
yer auld password.',
'noemail'                    => 'The\'r nae e-mail address recordit for uiser "$1".',
'passwordsent'               => 'A new password haes been sent tae the e-mail address registert for "$1". Please log in again efter ye receive it.',
'blocked-mailpassword'       => 'Yer IP address is blockit frae editin, sae it
canna uise the password recovery function, for tae prevent abuiss.',
'eauthentsent'               => "A confirmation email haes been sent tae the specifee'd email address.
Afore onie ither mail is sent tae the accoont, ye'll hae tae follae the guidance in the email,
tae confirm that ye ar aucht the accoont.",
'throttled-mailpassword'     => "A password minder haes been sent afore, in the laist {{PLURAL:$1|hoor|$1 hoors}}. To hinder abuise, juist the ''ae'' password minder will be sent in
{{PLURAL:$1|hoor|$1 hoors}}.",
'mailerror'                  => 'Error sendin mail: $1',
'acct_creation_throttle_hit' => 'Veesitors tae this wiki uisin yer IP address haev created $1 {{PLURAL:$1|accoont|accoonts}} the day, which is the maist permeettit in that lang.
Sae veesitors uisin this IP address canna mak ony mair accoonts juist noo.',
'emailauthenticated'         => 'Yer e-mail address wis checkit on $1.',
'emailnotauthenticated'      => 'Yer e-mail address hasnae been checkit! Nae e-mail
will be sent for ony o the followin featurs.',
'noemailprefs'               => "Nae email address haes been specifee'd, the follaein featurs willna wirk.",
'emailconfirmlink'           => 'Check yer e-mail address',
'invalidemailaddress'        => 'The email address canna be acceptit syne it seems tae be formattit wrang.
Please enter a weel-formattit address or mak that field tuim.',
'accountcreated'             => 'Accoont creatit',
'accountcreatedtext'         => 'The uiser accoont for $1 haes bin creatit.',
'createaccount-title'        => 'Accoont makin for {{SITENAME}}',
'createaccount-text'         => 'A body ($1) makit an accoont for yer email address on {{SITENAME}} ($4) cried "$2", wi a password o "$3".
Ye shuid log in an chynge yer password nou.

Ye dinna hae tae heed this message, if this accoont wis creatit by mistak.',
'loginlanguagelabel'         => 'Leid: $1',

# Change password dialog
'resetpass'                 => 'Chynge passwaird',
'resetpass_announce'        => 'Ye loggit in wi a short term e-mailed code. To be duin logging in, ye hae tae mak a new passwaird here:',
'resetpass_header'          => 'Chynge accoont password',
'oldpassword'               => 'Auld password',
'newpassword'               => 'New passwaird:',
'resetpass_submit'          => 'Mak passwaird an log in',
'resetpass_success'         => 'Yer passwaird chynge wis braw! Nou loggin ye in...',
'resetpass_forbidden'       => 'Passwords canna be chynged',
'resetpass-no-info'         => 'Ye maun be loggit in tae access this page directly.',
'resetpass-submit-loggedin' => 'Chynge passwaird',
'resetpass-submit-cancel'   => 'Cancel',

# Edit page toolbar
'bold_sample'     => 'Bauld text',
'bold_tip'        => 'Bauld text',
'italic_sample'   => 'Italic text',
'italic_tip'      => 'Italic text',
'link_sample'     => 'Airtin teitle',
'link_tip'        => 'Internal airtin',
'extlink_sample'  => 'http://www.example.com airtin teitle',
'extlink_tip'     => 'Airtin tae an outby steid (mynd the http:// prefix)',
'headline_sample' => 'Heidline text',
'headline_tip'    => 'Level 2 heidline',
'nowiki_sample'   => 'Insert non-formattit text here',
'nowiki_tip'      => 'Ignore wiki formattin',
'image_sample'    => 'Exemplar.jpg',
'image_tip'       => 'Embeddit eimage',
'media_sample'    => 'Exemplar.ogg',
'media_tip'       => 'Media file airtin',
'sig_tip'         => 'Yer seignatur wi timestamp',
'hr_tip'          => 'Horizontal line (dinna ower uise)',

# Edit pages
'summary'                          => 'Ootline:',
'subject'                          => 'Subject/headline:',
'minoredit'                        => 'This is a smaa edit',
'watchthis'                        => 'Leuk ower this page',
'savearticle'                      => 'Hain page',
'preview'                          => 'Scance',
'showpreview'                      => 'Scance ower',
'showlivepreview'                  => 'Live leuk ower',
'showdiff'                         => 'Shaw chynges',
'anoneditwarning'                  => "Ye arna loggit in. Yer IP address will be recordit in this page's edit history.",
'missingsummary'                   => "'''Mynd:''' Ye hivna gien an edit summary. Gin ye dab on Hain again, yer edit will be haint athoot ane.",
'missingcommenttext'               => 'Please enter a comment ablo.',
'missingcommentheader'             => "'''Mynd:''' Ye hivna gien a subject/heidline for this comment. Gin ye dab on Hain again, yer edit will be haint athoot ane.",
'summary-preview'                  => 'Ootline leuk ower:',
'subject-preview'                  => 'Subject/headline leuk ower:',
'blockedtitle'                     => 'Uiser is blockit',
'blockedtext'                      => '\'\'\'Yer uisername or IP address haes been blockit.\'\'\'

The block was made bi $1. The raeson gien is \'\'$2\'\'.

* Start of block: $8
* Expiry of block: $6
* Intended blockee: $7

Ye can contact $1 or ane o the ither [[{{MediaWiki:Grouppage-sysop}}|administrators]] tae discuss the block.
Mynd that ye canna uise the "email this uiser" featur unless ye hae a valid email address registert in yer [[Special:Preferences|uiser preferences]] an ye hae not been blocked from using it.
Yer IP address is $3, and the block ID is #$5. Please include this address in onie queries ye mak.',
'autoblockedtext'                  => 'Sairy, but yer IP address haes been blockit by the seestem acause it wis uised by an ither uiser, that wis blockit by $1.
The grunds for this were:

:\'\'$2\'\'

* Stairt o block: $8
* End o block: $6

Ye may contact $1 or ane o the ither
[[{{MediaWiki:Grouppage-sysop}}|sysops]] tae argie the block.

Please jot that ye cannae uise the "e-mail this uiser" featur unless ye hae a habile e-mail address
registerit in yer [[Special:Preferences|uiser preferences]] an ye hinna been blockit frae uisin it.

Yer block ID is $5. Please include this ID in ony argies ye mak.',
'blockednoreason'                  => 'nae grunds put',
'whitelistedittext'                => 'Ye hae tae $1 tae edit pages.',
'confirmedittext'                  => 'Ye maun confirm yer e-mail address afore editin pages. Please set an validate yer e-mail address throu yer [[Special:Preferences|uiser settins]].',
'nosuchsectiontitle'               => 'There isnae a section wi that teetle',
'nosuchsectiontext'                => 'Yer tryin tae edit a section that isnae there.',
'loginreqtitle'                    => 'Login Requirit!',
'loginreqlink'                     => 'log in',
'loginreqpagetext'                 => 'Ye maun $1 tae view ither pages.',
'accmailtitle'                     => 'Passwaird sent.',
'accmailtext'                      => "The Password for '$1' haes been sent tae $2.",
'newarticle'                       => '(New)',
'newarticletext'                   => "Ye'v follaed an airtin til a page that disna exist yet. Tae create the page, stert typin in the box ablo (see the [[{{MediaWiki:Helppage}}|help page]] for mair info). Gin ye'r here by mistak, juist dab yer brouser's '''back''' button.",
'anontalkpagetext'                 => "----''This is the collogue page for a nameless uiser that haesna made an accoont yet or that disna uise it. We syne hiv tae uise the numerical IP address tae identifee thaim. Sic an IP address can be shared bi a wheen o uisers. Gin you ar a nameless uiser an feel that irrelevant comments haes been directit at ye, please [[Special:UserLogin|mak an accoont or log in]] tae evyte futur confusion wi ither nameless uisers.''",
'noarticletext'                    => 'The\'r nae text on this page the nou. 
Ye can [[Special:Search/{{PAGENAME}}|rake for this page teitle]] in ither pages,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} rake th\' related logs],
 or [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page].</span>',
'noarticletext-nopermission'       => 'The\'r nae text on this page the nou. 
Ye ken [[Special:Search/{{PAGENAME}}|rake for this page teitle]] in ither pages,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} rake th\' related logs].',
'userpage-userdoesnotexist'        => 'Uiser accoont "<nowiki>$1</nowiki>" hasnae been registerit. Please check gin ye wint tae mak or edit this page.',
'clearyourcache'                   => "'''Tak tent:''' Efter hainin, ye micht hae tae bypass yer brouser's cache for tae see the chynges. '''Mozilla / Firefox / Safari:''' haud doun ''Shift'' while dabbin on ''Reload'', or press ''Ctrl-Shift-R'' (''Cmd-Shift-R'' on Apple Mac); '''IE:''' haud doun ''Ctrl'' while dabbin on ''Refresh'', or press ''Ctrl-F5''; '''Konqueror:''' juist dab on the ''Reload'' button, or press ''F5''; '''Opera''' users micht hae tae haillie dicht thair cache in ''Tools&rarr;Preferences''.",
'usercssyoucanpreview'             => "'''Tip:''' Uise the 'Show preview' button tae proof yer new CSS afore savin.",
'userjsyoucanpreview'              => "'''Tip:''' Uise the 'Show preview' button tae proof yer new JS afore savin.",
'usercsspreview'                   => "'''Mynd that ye'r juist previewin yer uiser CSS, it haesna yet been hained!'''",
'userjspreview'                    => "'''Mynd that ye're juist testin/previewing yer uiser JavaScript; it haesna been hained yet!'''",
'userinvalidcssjstitle'            => "'''Warnin:''' There isnae a skin \"\$1\". Mynd that yer ain .css an .js pages uise a lowercase teetle, e.g. {{ns:user}}:Foo/vector.css instead o {{ns:user}}:Foo/Vector.css.",
'updated'                          => '(Updatit)',
'note'                             => "'''Mynd:'''",
'previewnote'                      => "'''Mynd that this is juist a scance-ower, an haesna been hained yet!'''",
'previewconflict'                  => 'This scance reflects the text in the upper text editin area like it will kythe gin ye chuise tae save.',
'session_fail_preview'             => "'''Sairy! We culdnae process yer edit acause o a loss o term data.
Please try again. Gin it disnae wairk still, try loggin oot an loggin in again.'''",
'session_fail_preview_html'        => "'''Sairy! We culdnae process yer edit acause o a loss o term data.'''

''Acause this wiki haes raw HTML habile, the leuk ower is hidden tae hinder JavaScript attacks.''

'''Gin this is a proper edit try, please try again. Gin it disnae wairk still, try loggin oot an loggin back in.'''",
'token_suffix_mismatch'            => "'''Yer edit haes been rejectit acause yer client made a richt mess o the punctuation characters
in the edit token. The edit haes been rejectit tae hinder corruption o the page text.
This whiles happens when ye are uisin a bruken web-based anonymous proxy service.'''",
'editing'                          => 'Editin $1',
'editingsection'                   => 'Editin $1 (section)',
'editingcomment'                   => 'Editin $1 (comment)',
'editconflict'                     => 'Edit conflict: $1',
'explainconflict'                  => "Some ither body haes chynged this page syne ye stertit editin it.
The upper text area hauds the page text as it currently exists.
Yer chynges is shawn in the lower text area.
Ye'll hae tae merge yer chynges intae the existin text.
'''Juist''' the text in the upper text area will be hained whan ye press \"{{int:savearticle}}\".",
'yourtext'                         => 'Yer text',
'storedversion'                    => 'Storit version',
'nonunicodebrowser'                => "'''WARNIN: Yer brouser isna unicode compliant.  The'r a wirkaroond tae allou ye tae sauflie edit airticles: non-ASCII characters will kythe in the edit box as hexadecimal codes.'''",
'editingold'                       => "'''WARNIN: Ye'r editin an oot-o-date reveision o this page. Gin ye hain it, onie chynges made syne this reveision will be lost.'''",
'yourdiff'                         => 'Differs',
'copyrightwarning'                 => "Please mynd that aa contreibutions tae {{SITENAME}} is conseidert tae be released unner the $2 (see $1 for details). Gin ye dinna want yer writin tae be editit athoot mercy an redistribute at will, than dinna submit it here.<br /> Forbye thon, ye'r promisin us that ye wrat this yersel, or copied it frae a public domain or siclike free resoorce. '''DINNA SUBMIT COPYRICHTIT WARK ATHOOT PERMEISSION!'''",
'copyrightwarning2'                => "Please mynd that aa contreibutions tae {{SITENAME}} micht be editit, chynged, or remuved bi ither contreibutors.
Gin ye dinna want yer writin tae be editit athoot mercy and redistribute at will, than dinna submit it here.<br />
YYe'r promisin us forbye that ye wrat this yersel, or copied it frae a
public domain or siclike free resoorce (see $1 for details).
'''DINNA SUBMIT COPYRICHTIT WARK ATHOOT PERMEISSION!'''",
'longpageerror'                    => "'''ERROR: The text ye hae submitted is $1 kilobytes
lang, an that's langer than the maximum of $2 kilobytes. It canna be hained.'''",
'readonlywarning'                  => "WARNIN: The database haes been lockit for maintenance, sae ye'll no can hain yer edits richt nou. Ye micht wish tae cut-n-paste the text intil a text file an hain it for later.",
'protectedpagewarning'             => "'''WARNIN: This page haes been lockit sae that juist uisers wi administrator privileges can edit it.'''",
'semiprotectedpagewarning'         => "'''Warnin:''' This page haes been lockit sae that only registerit uisers can edit it.",
'cascadeprotectedwarning'          => "'''Warnin:''' This page haes been lockit sae that only uisers wi sysop richts can edit it, acause it is includit in the followin cascade-protectit {{PLURAL:$1|page|pages}}:",
'templatesused'                    => '{{PLURAL:$1|Template|Templates}} used on this page:',
'templatesusedpreview'             => 'Templates uised in this scance ower:',
'templatesusedsection'             => 'Templates uised in this section:',
'template-protected'               => '(protectit)',
'template-semiprotected'           => '(semi-protectit)',
'hiddencategories'                 => 'This page is a member of {{PLURAL:$1|1 hidden category|$1 hidden categories}}:',
'nocreatetitle'                    => 'Page makkin limitit',
'nocreatetext'                     => 'This site haes restrictit the ability to mak new pages.
Ye can go back an eik tae an existing page, or [[Special:UserLogin|log in or mak an accoont]].',
'nocreate-loggedin'                => 'Ye dinnae hae the richts tae mak new pages on this wiki.',
'permissionserrors'                => 'Richts Errors',
'permissionserrorstext'            => 'Ye dinnae hae the richts tae dae that, acause o the followin {{PLURAL:$1|grund|grunds}}:',
'permissionserrorstext-withaction' => 'Ye dinna hae the richts tae $2, for the follaein {{PLURAL:$1|reason|reasons}}:',
'recreate-moveddeleted-warn'       => "'''Warnin: Ye are makkin a page that haes been deletit.'''

Ye shuld check that it is guid tae keep editin this page.
The deletion and flit log for this page is providit here:",
'moveddeleted-notice'              => 'This page haes bin deletit. 
The deletion and flit log fur the page are provided below fur reference.',

# Parser/template warnings
'post-expand-template-inclusion-warning'  => "'''Wairnin:''' Template include size is tae lairge. 
Some templates wull nae be included.",
'post-expand-template-inclusion-category' => 'Pages whaur template include size is exceeded',
'post-expand-template-argument-warning'   => 'Tak tent: This page hauds at least the ae template argument that haes an ower muckle expansion size.
Thae arguments hae been left oot.',
'post-expand-template-argument-category'  => 'Pages containing omitted template arguments',

# "Undo" feature
'undo-success' => 'The edit can be undone. Please check the chynges albo tae check that this is whit ye wint tae dae, an then hain the chynges albo tae be duin undooin the edit.',
'undo-failure' => 'The edit culdnae be undone acause o conflictin edits inatween.',
'undo-summary' => 'Undo reveision $1 by [[Special:Contributions/$2|$2]] ([[User talk:$2|Collogue]])',

# Account creation failure
'cantcreateaccounttitle' => 'Canna mak accoont',
'cantcreateaccount-text' => "Accoont makkin frae this IP address ('''$1''') haes been blockit by [[User:$3|$3]].

The grund for this, given by $3 is ''$2''",

# History pages
'viewpagelogs'           => 'Leuk at logs for this page',
'nohistory'              => "The'r nae edit history for this page.",
'currentrev'             => 'Current reveision',
'currentrev-asof'        => 'Latest revision as of $1',
'revisionasof'           => 'Reveision as o $1',
'revision-info'          => 'Revision as o $1 by $2',
'previousrevision'       => '← Aulder reveision',
'nextrevision'           => 'Newer reveision →',
'currentrevisionlink'    => 'see current reveision',
'cur'                    => 'nou',
'next'                   => 'neist',
'last'                   => 'hind',
'page_first'             => 'first',
'page_last'              => 'hindermaist',
'histlegend'             => 'Diff selection: mairk the radio boxes o the versions tae compare an press enter or the button at the bottom.<br /> Legend: (cur) = difference frae current version, (last) = difference frae foregaun version, s = smaa edit.',
'history-fieldset-title' => 'Browse history',
'history-show-deleted'   => 'Deletit only',
'histfirst'              => 'Foremaist',
'histlast'               => 'Hindermaist',
'historysize'            => '({{PLURAL:$1|1 byte|$1 bytes}})',
'historyempty'           => '(empie)',

# Revision feed
'history-feed-title'          => 'Revision history',
'history-feed-description'    => 'Revision history for this page on the wiki',
'history-feed-item-nocomment' => '$1 at $2',
'history-feed-empty'          => 'The requestit page disnae exist.
It micht hae been deletit frae the wiki, or the name micht hae been chynged.
Try [[Special:Search|rakin on the wiki]] for new pages ye micht be interestit in.',

# Revision deletion
'rev-deleted-comment'         => '(jottin removit)',
'rev-deleted-user'            => '(uisername removit)',
'rev-deleted-event'           => '(entry removit)',
'rev-deleted-text-permission' => 'This page revision haes been removit frae the public archives.
There micht be parteeculars in the [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} deletion log].',
'rev-deleted-text-view'       => 'This page revision haes been removit frae the public archives.
Acause yer an admeenistrator on this site, ye can leuk at it;
there micht be parteeculars in the [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} deletion log].',
'rev-delundel'                => 'shaw/scug',
'revisiondelete'              => 'Delete/undelete revisions',
'revdelete-nooldid-title'     => 'Nae target revision',
'revdelete-radio-set'         => 'Yea',
'revdelete-radio-unset'       => 'Nae',
'revdel-restore'              => 'change visibility',
'revdel-restore-deleted'      => 'deletit revisions',
'revdel-restore-visible'      => 'visible revisions',
'pagehist'                    => 'Page history',

# History merging
'mergehistory-from'   => 'Soorce page:',
'mergehistory-reason' => 'Raeson:',

# Merge log
'revertmerge' => 'Unmerge',

# Diffs
'history-title'           => 'Revision history of "$1"',
'difference'              => '(Difference atween revisions)',
'lineno'                  => 'Line $1:',
'compareselectedversions' => 'Compare selectit versions',
'editundo'                => 'undo',
'diff-multi'              => '({{PLURAL:$1|One intermediate revision|$1 intermediate revisions}} by {{PLURAL:$2|one user|$2 users}} nae shown)',

# Search results
'searchresults'                    => 'Rake results',
'searchresults-title'              => 'Rake affcome for "$1"',
'searchresulttext'                 => 'For mair information aboot rakin {{SITENAME}}, see [[{{MediaWiki:Helppage}}|Rakin {{SITENAME}}]].',
'searchsubtitle'                   => "Ye raked for '''[[:$1]]'''",
'searchsubtitleinvalid'            => "Ye raked for '''$1'''",
'titlematches'                     => 'Airticle teitle matches',
'notitlematches'                   => 'Nae page teitle matches',
'notextmatches'                    => 'Nae page text matches',
'prevn'                            => 'foregaun {{PLURAL:$1|$1}}',
'nextn'                            => 'neist {{PLURAL:$1|$1}}',
'prevn-title'                      => 'Previous $1 {{PLURAL:$1|ootcome|ootcomes}}',
'nextn-title'                      => 'Next $1 {{PLURAL:$1|ootcome|ootcomes}}',
'shown-title'                      => 'Shaw $1 {{PLURAL:$1|ootcome|ootcomes}} per page',
'viewprevnext'                     => 'View ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-exists'                => "'''There is a page named \"[[:\$1]]\" oan this wiki.'''",
'searchmenu-new'                   => "'''Mak the page \"[[:\$1]]\" on this wiki!'''",
'searchhelp-url'                   => 'Help:Contents',
'searchprofile-articles'           => 'Content pages',
'searchprofile-project'            => 'Help and Project pages',
'searchprofile-images'             => 'Multimedia',
'searchprofile-everything'         => 'Everything',
'searchprofile-advanced'           => 'Advanced',
'searchprofile-articles-tooltip'   => 'Rake in $1',
'searchprofile-project-tooltip'    => 'Rake in $1',
'searchprofile-images-tooltip'     => 'Rake fur files',
'searchprofile-everything-tooltip' => 'Rake aw of content (including collogue pages)',
'searchprofile-advanced-tooltip'   => 'Rake in custom namespaces',
'search-result-size'               => '$1 ({{PLURAL:$2|1 word|$2 words}})',
'search-result-category-size'      => '{{PLURAL:$1|1 member|$1 members}} ({{PLURAL:$2|1 subcategory|$2 subcategories}}, {{PLURAL:$3|1 file|$3 files}})',
'search-redirect'                  => '(redirect $1)',
'search-section'                   => '(section $1)',
'search-suggest'                   => 'Did ye mean: $1',
'search-interwiki-more'            => '(more)',
'search-mwsuggest-enabled'         => 'wi suggestions',
'search-mwsuggest-disabled'        => 'nae propone',
'searchrelated'                    => 'related',
'searchall'                        => 'aw',
'showingresults'                   => "Shawin ablo up tae {{PLURAL:$1|'''1''' result|'''$1''' results}} stertin wi #'''$2'''.",
'showingresultsnum'                => "Shawin ablo {{PLURAL:$3|'''1''' result|'''$3''' results}} stertin wi #'''$2'''.",
'showingresultsheader'             => "{{PLURAL:$5|Ootcome '''$1''' of '''$3'''|Ootcomes '''$1 - $2''' of '''$3'''}} for '''$4'''",
'nonefound'                        => "'''Mynd''': unsuccessfu rakes is afttimes caused bi rakin for common words like \"hae\" an \"frae\", that isna indexed, or bi specifeein mair nor ae rake term (juist pages haudin aa the rake terms will kythe in the result).",
'search-nonefound'                 => "Thare wur na ootcomes matching th' query.",
'powersearch'                      => 'Rake',
'powersearch-redir'                => 'Leet redirects',
'powersearch-field'                => 'Rake for',
'powersearch-toggleall'            => 'Aw',
'searchdisabled'                   => 'Rakin throu {{SITENAME}} is disabled for performance raesons. Ye can rake via Google juist nou. Mynd that thair indexes o {{SITENAME}} content micht be oot o date.',

# Quickbar
'qbsettings-none' => 'Nane',

# Preferences page
'mypreferences'             => 'Ma preferences',
'prefsnologin'              => 'No loggit in',
'prefsnologintext'          => 'Ye maun be [[Special:UserLogin|loggit in]] tae set uiser preferences.',
'changepassword'            => 'Chynge password',
'prefs-skin'                => 'Huil',
'skin-preview'              => 'First Leuk',
'datedefault'               => 'Nae preference',
'prefs-datetime'            => 'Date an time',
'prefs-personal'            => 'Uiser data',
'prefs-rc'                  => 'Recent chynges an shawin stubs',
'prefs-watchlist'           => 'Watchleet',
'prefs-misc'                => 'Antrin settins',
'prefs-resetpass'           => 'Chynge passwaird',
'saveprefs'                 => 'Hain preferences',
'prefs-editing'             => 'Editin',
'searchresultshead'         => 'Rake result settins',
'resultsperpage'            => 'Hits tae shaw per page',
'stub-threshold-disabled'   => 'Tuckie',
'recentchangescount'        => 'Nummer o teitles in recent chynges',
'savedprefs'                => 'Yer preferences haes been hained.',
'timezoneoffset'            => 'Affset',
'servertime'                => 'Server time is nou',
'guesstimezone'             => 'Fill in frae brouser',
'allowemail'                => 'Allou email frae ither uisers',
'defaultns'                 => 'Rake in thir namespaces bi defaut:',
'default'                   => 'defaut',
'prefs-files'               => 'Files',
'prefs-custom-css'          => 'Custom CSS',
'prefs-custom-js'           => 'Custom JS',
'youremail'                 => 'Yer email:',
'username'                  => 'Uisername:',
'uid'                       => 'Uiser ID:',
'prefs-memberingroups'      => 'Member o {{PLURAL:$1|group|groups}}:',
'yourrealname'              => 'Yer real name:',
'yourlanguage'              => 'Interface leid:',
'yourvariant'               => 'Leid variant',
'yournick'                  => 'New seegnatur:',
'badsig'                    => 'Raw signature nae guid; check HTML tags.',
'badsiglength'              => 'Yer nickname is ower lang; it haes tae be $1 {{PLURAL:$1|character|characters}} or less.',
'email'                     => 'E-mail',
'prefs-help-realname'       => 'Rael name is optional an gin ye chuise tae provide it this will be uised tae gie ye attreibution for yer wark.',
'prefs-help-email'          => 'E-mail is optional, bit is needed fur password resets, shuid ye forget yer password.',
'prefs-help-email-others'   => "Ye kin an choose tae let others contact ye by e-mail thro' a link oan yer uiser or collogue  page. 
Yer e-mail address insae revealed whin ither uisers contact ye.",
'prefs-help-email-required' => 'Yer e-mail address is needit.',
'prefs-diffs'               => 'Diffs',

# User rights
'userrights-lookup-user'   => 'Manish uiser boorachs',
'userrights-user-editname' => 'Enter a uisername:',
'editusergroup'            => 'Edit uiser boorach',
'editinguser'              => "Editin uiser '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
'userrights-groupsmember'  => 'Member o:',

# Groups
'group-user' => 'Uisers',
'group-bot'  => 'Bots',
'group-all'  => '(aw)',

'group-user-member' => 'Uiser',
'group-bot-member'  => 'Bot',

# Rights
'right-delete' => 'Delete pages',

# User rights log
'rightslog'     => 'Uiser richts log',
'rightslogtext' => 'This is a log o chynges tae uiser richts.',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'edit this page',

# Recent changes
'nchanges'                          => '$1 {{PLURAL:$1|chynge|chynges}}',
'recentchanges'                     => 'Recent chynges',
'recentchanges-legend'              => 'Recent changes options',
'recentchangestext'                 => 'Follae the maist recent chynges tae the wiki on this page.',
'recentchanges-feed-description'    => 'Follae the maist recent chynges tae the wiki in this feed.',
'recentchanges-label-newpage'       => 'This edit created a freish page',
'recentchanges-label-minor'         => 'This is a smaa edit',
'recentchanges-label-bot'           => 'This edit wis performed by a bot',
'recentchanges-label-unpatrolled'   => 'This edit haes nae yet bin patrolled',
'rcnote'                            => "Below {{PLURAL:$1|is '''1''' change|are the last '''$1''' chynges}} in the last {{PLURAL:$2|day|'''$2''' days}}, as of $5, $4.",
'rcnotefrom'                        => 'Ablo is the chynges syne <b>$2</b> (up tae <b>$1</b> shawn).',
'rclistfrom'                        => 'Shaw new chynges stertin frae $1',
'rcshowhideminor'                   => '$1 smaa edits',
'rcshowhidebots'                    => '$1 bots',
'rcshowhideliu'                     => '$1 logged-in uisers',
'rcshowhideanons'                   => '$1 anonymous uisers',
'rcshowhidepatr'                    => '$1 patrolled edits',
'rcshowhidemine'                    => '$1 ma edits',
'rclinks'                           => 'Shaw last $1 chynges in last $2 days<br />$3',
'diff'                              => 'diff',
'hist'                              => 'hist',
'hide'                              => 'Hod',
'show'                              => 'shaw',
'minoreditletter'                   => 's',
'newpageletter'                     => 'N',
'boteditletter'                     => 'b',
'number_of_watching_users_pageview' => '[$1 watchin {{PLURAL:$1|uiser|uisers}}]',
'rc_categories_any'                 => 'Ony',
'rc-enhanced-expand'                => 'Shaw details (requires JavaScript)',
'rc-enhanced-hide'                  => 'Hod details',

# Recent changes linked
'recentchangeslinked'          => 'Relatit chynges',
'recentchangeslinked-feed'     => 'Relatit chynges',
'recentchangeslinked-toolbox'  => 'Relatit chynges',
'recentchangeslinked-title'    => 'Changes related to "$1"',
'recentchangeslinked-noresult' => "Na changes oan linked pages during th' given period.",
'recentchangeslinked-summary'  => "This is a leet o' changes made recently tae pages linked frae a specified page (or tae members o' a specified category).
Pages on [[Special:Watchlist|your watchleet]] are '''bold'''.",
'recentchangeslinked-page'     => 'Page name:',
'recentchangeslinked-to'       => "Shaw changes tae pages linked tae th' given page instead",

# Upload
'upload'                      => 'Uplaid file',
'uploadbtn'                   => 'Uplaid file',
'reuploaddesc'                => 'Gang back tae the uplaid form.',
'uploadnologin'               => 'Nae loggit in',
'uploadnologintext'           => 'Ye maun be [[Special:UserLogin|loggit in]] til uplaid files.',
'uploaderror'                 => 'Uplaid error',
'uploadtext'                  => "Uise the form ablo tae uplaid new files;
tae keek at or rake throu aareadies uplaidit eimages gang tae the [[Special:FileList|leet o uplaidit files]];
uplaids an deletions is recordit in the [[Special:Log|project log]].

Tae pit the eimage intae a page, uise an airtin i the form
'''<nowiki>[[</nowiki>{{ns:file}}:file.jpg<nowiki>]]</nowiki>''',
'''<nowiki>[[</nowiki>{{ns:file}}:file.png|alt text<nowiki>]]</nowiki>''' or
'''<nowiki>[[</nowiki>{{ns:media}}:file.ogg<nowiki>]]</nowiki>''' for pyntin strecht tae the file",
'uploadlog'                   => 'uplaid log',
'uploadlogpage'               => 'Uplaid log',
'uploadlogpagetext'           => 'Ablo is a leet o the maist recent file uplaids.',
'filedesc'                    => 'Ootline',
'filestatus'                  => 'Copyricht status:',
'filesource'                  => 'Soorce:',
'uploadedfiles'               => 'Uplaidit files',
'ignorewarning'               => 'Ignore warnin an hain file oniewey.',
'ignorewarnings'              => 'Ignore ony warnins',
'illegalfilename'             => 'The filename "$1" haes characters that isna alloud in page teitles. Please rename the file an gie uplaidin it anither shot.',
'badfilename'                 => 'Eimage name haes been chynged tae "$1".',
'largefileserver'             => 'This file is bigger nor the server is confeigurt tae allou.',
'fileexists'                  => "A file wi this name exists aareadies, please check <strong>[[:$1]]</strong> gin ye'r no siccar that ye want tae chynge it.
[[$1|thumb]]",
'fileexists-forbidden'        => 'A file wi this name aareadies exists; please gang back an uplaid this file unner a new name. [[File:$1|thumb|center|$1]]',
'fileexists-shared-forbidden' => 'A file wi this name aareadies exists in the shared file depose; please gang back an uplaid this file unner a new name. [[File:$1|thumb|center|$1]]',
'uploadwarning'               => 'Uplaid warnin',
'savefile'                    => 'Hain file',
'uploadedimage'               => 'uplaidit "$1"',
'uploaddisabled'              => 'Sorry, uplaidin is disabled.',
'uploadscripted'              => 'This file hauds HTML or script code that micht be wrang interpretit bi a wab brouser.',
'uploadvirus'                 => 'The file hauds a virus! Details: $1',
'sourcefilename'              => 'Soorce filename:',

'license'        => 'Licensing:',
'license-header' => 'Licensing',
'nolicense'      => 'Nane selected',

# Special:ListFiles
'imgfile'        => 'file',
'listfiles'      => 'Eimage leet',
'listfiles_name' => 'Name',
'listfiles_user' => 'Uiser',
'listfiles_size' => 'Size',

# File description page
'file-anchor-link'       => 'Eimage',
'filehist'               => 'File history',
'filehist-help'          => "Click oan a date/time tae view th' file as it appeared at that time.",
'filehist-deleteone'     => 'delete',
'filehist-revert'        => 'revert',
'filehist-current'       => 'current',
'filehist-datetime'      => 'Date/Time',
'filehist-thumb'         => 'Thumbnail',
'filehist-thumbtext'     => 'Thumbnail for version as of $1',
'filehist-user'          => 'Uiser',
'filehist-dimensions'    => 'Dimensions',
'filehist-comment'       => 'Comment',
'imagelinks'             => 'File airtins',
'linkstoimage'           => 'The follaein {{PLURAL:$1|page airts|$1 pages airt}} tae this file:',
'nolinkstoimage'         => "The'r nae pages airts tae this eimage.",
'sharedupload-desc-here' => "This file is frae $1 and may be used bi other projects.
Th' description oan tis [$2 file description page] thare is shown below.",

# File reversion
'filerevert'        => 'Revert $1',
'filerevert-legend' => 'Revert file',
'filerevert-submit' => 'Revert',

# File deletion
'filedelete-submit' => 'Delete',

# MIME search
'mimetype' => 'MIME type:',
'download' => 'dounlaid',

# Unused templates
'unusedtemplates'     => 'Templates that arena uised',
'unusedtemplatestext' => 'This page leets aw pages in the template namespace that haena been uised in anither page. Mynd an check for ither links tae the templates afore deletin them.',
'unusedtemplateswlh'  => 'ither links',

# Random page
'randompage' => 'Wale page allevolie',

# Statistics
'statistics'              => 'Statistics',
'statistics-header-pages' => 'Page statistics',
'statistics-header-edits' => 'Edit statistics',
'statistics-header-views' => 'View statistics',
'statistics-header-users' => 'Uiser statistics',
'statistics-header-hooks' => 'Ither statistics',
'statistics-pages'        => 'Pages',

'disambiguationspage' => 'Template:disambig',

'doubleredirects'     => 'Dooble reguidals',
'doubleredirectstext' => 'Ilka raw hauds airtins tae the first an saicont reguidal, as weel as the first line o the saicont reguidal text, for usual giein the "rael" tairget page, that the first reguidal shuid pynt til.',

'brokenredirects'        => 'Brucken reguidals',
'brokenredirectstext'    => 'The follaein reguidals airts tae pages that disna exist.',
'brokenredirects-edit'   => 'edit',
'brokenredirects-delete' => 'delete',

'withoutinterwiki'        => 'Pages athoot leid links',
'withoutinterwiki-legend' => 'Prefix',
'withoutinterwiki-submit' => 'Shaw',

# Miscellaneous special pages
'nbytes'                  => '$1 {{PLURAL:$1|byte|bytes}}',
'ncategories'             => '$1 {{PLURAL:$1|category|categories}}',
'nlinks'                  => '$1 {{PLURAL:$1|link|links}}',
'nmembers'                => '$1 {{PLURAL:$1|membir|membirs}}',
'nrevisions'              => '$1 {{PLURAL:$1|reveision|reveisions}}',
'nviews'                  => '$1 {{PLURAL:$1|view|views}}',
'uncategorizedpages'      => 'Uncategoreised pages',
'uncategorizedcategories' => 'Uncategoreised categories',
'unusedcategories'        => 'Unuised categories',
'unusedimages'            => 'Unuised images',
'wantedcategories'        => 'Wantit categories',
'wantedpages'             => 'Wantit pages',
'mostlinked'              => 'Maist airtit-til pages',
'mostlinkedcategories'    => 'Maist airtit-til categories',
'mostcategories'          => 'Airticles wi the maist categories',
'mostimages'              => 'Maist uised eimages',
'mostrevisions'           => 'Maist revised airticles',
'prefixindex'             => 'All pages with prefix',
'longpages'               => 'Lang pages',
'deadendpages'            => 'Deid-end pages',
'listusers'               => 'Uiser leet',
'usercreated'             => 'Created on $1 at $2',
'newpages'                => 'New pages',
'newpages-username'       => 'Uisername:',
'ancientpages'            => 'Auldest pages',
'move'                    => 'Flit',
'movethispage'            => 'Flit this page',
'unusedimagestext'        => '<p>Please mynd that ither wabsteids micht airt til an eimage wi a direct URL, an sae micht still be leetit here but be in aictive uiss.</p>',
'unusedcategoriestext'    => 'The follaein category pages exists, tho nae ither airticle or category maks uiss o thaim.',
'notargettitle'           => 'Nae target',
'notargettext'            => "Ye hivna specifee'd a tairget page or uiser tae perform this function on.",
'pager-newer-n'           => '{{PLURAL:$1|newer 1|newer $1}}',
'pager-older-n'           => '{{PLURAL:$1|older 1|older $1}}',

# Book sources
'booksources'               => 'Beuk sources',
'booksources-search-legend' => 'Search fur book sources',
'booksources-go'            => 'Gang',

# Special:Log
'specialloguserlabel'  => 'Uiser:',
'speciallogtitlelabel' => 'Teitle:',
'log'                  => 'Logs',
'all-logs-page'        => 'Aw public logs',
'alllogstext'          => 'Combined display o uplaid, deletion, protection, blockin, an administrator logs. Ye can narra doon the view bi walin a log type, the uiser name, or the affectit page.',
'logempty'             => 'Nae matchin items in log.',

# Special:AllPages
'allpages'          => 'Aa pages',
'alphaindexline'    => '$1 tae $2',
'nextpage'          => 'Neist page ($1)',
'prevpage'          => 'Page afore ($1)',
'allpagesfrom'      => 'Shaw pages stairtin at:',
'allarticles'       => 'Aa airticles',
'allinnamespace'    => 'Aa pages ($1 namespace)',
'allnotinnamespace' => 'Aa pages (nae in $1 namespace)',
'allpagesprev'      => 'Afore-gaun',
'allpagesnext'      => 'Neist',
'allpagessubmit'    => 'Gang',
'allpagesprefix'    => 'Shaw pages wi prefix:',
'allpagesbadtitle'  => 'The page teitle gien wis wrang or haed a cross-lied or cross-wiki prefix. It micht hae ane or twa characters that canna be uised in teitles',
'allpages-bad-ns'   => '{{SITENAME}} disna hae a namespace "$1".',

# Special:Categories
'categories'                    => 'Categories',
'categoriespagetext'            => 'The follaein categories exist in the wiki.
[[Special:UnusedCategories|Unused categories]] are not shown here.
Also see [[Special:WantedCategories|wanted categories]].',
'special-categories-sort-count' => 'sairt bi coont',
'special-categories-sort-abc'   => 'sairt by the alphabet',

# Special:DeletedContributions
'sp-deletedcontributions-contribs' => 'contreibutions',

# Special:LinkSearch
'linksearch-ns'   => 'Namespace:',
'linksearch-ok'   => 'Rake',
'linksearch-line' => '$1 is linked from $2',

# Special:ListUsers
'listusers-submit'  => 'Shaw',
'listusers-blocked' => '(blockit)',

# Special:Log/newusers
'newuserlogpage' => 'Uiser creation log',

# Special:ListGroupRights
'listgrouprights-members' => '(leet o members)',

# Email user
'mailnologin'     => 'Nae send address',
'mailnologintext' => 'Ye maun be [[Special:UserLogin|loggit in]] an hae a valid e-mail address in yer [[Special:Preferences|preferences]] tae send e-mail til ither uisers.',
'emailuser'       => 'E-mail this uiser',
'noemailtitle'    => 'Nae e-mail address',
'noemailtext'     => "This uiser haesna specifee'd a valid e-mail address, or haes chuisen no tae receive e-mail frae ither uisers.",
'emailmessage'    => 'Message:',

# Watchlist
'watchlist'         => 'Ma watchleet',
'mywatchlist'       => 'Ma watchleet',
'watchlistfor2'     => 'For $1 $2',
'nowatchlist'       => 'Ye hivna onie eitems on yer watchleet.',
'watchnologin'      => 'Nae loggit in',
'watchnologintext'  => 'Ye maun be [[Special:UserLogin|loggit in]] tae modify yer watchleet.',
'addedwatchtext'    => "The page \"<nowiki>\$1</nowiki>\" haes been eikit ti yer [[Special:Watchlist|watchleet]]. Futur chynges ti this page an its associate Collogue page will be leetit thare, an the page will kythe '''bauldit''' in the [[Special:RecentChanges|leet o recent chynges]] ti mak it mair eith tae pick oot. <p>Gin ye want ti remuve the page frae yer watchleet later, dab \"Stop watching\" in the sidebar.",
'removedwatchtext'  => 'The page "[[:$1]]" haes been remuved frae yer watchleet.',
'watch'             => 'Watch',
'watchthispage'     => 'Leuk ower this page',
'unwatch'           => 'Unwatch',
'notanarticle'      => 'No a content page',
'watchnochange'     => 'Nane o yer watched items were edited in the time period displayed.',
'watchlist-details' => "{{PLURAL:$1|$1 page|$1 pages}} on yer watchleet, nae countin' collogue pages.",
'watchlistcontains' => 'Yer watchleet contains $1 {{PLURAL:$1|page|pages}}.',
'iteminvalidname'   => "Trouble wi eitem '$1', invalid name...",
'wlnote'            => "Ablo is the lest $1 {{PLURAL:$1|chynge|chynges}} in the lest {{PLURAL:$2|hour|'''$2''' hours}}.",
'wlshowlast'        => 'Shaw lest $1 hours $2 days $3',
'watchlist-options' => 'Watchleet options',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Watchin...',
'unwatching' => 'Unwatchin...',

'enotif_reset'       => 'Merk aa pages visitit',
'changed'            => 'chynged',
'created'            => 'creatit',
'enotif_subject'     => '{{SITENAME}} page $PAGETITLE haes been $CHANGEDORCREATED bi $PAGEEDITOR',
'enotif_lastvisited' => 'Hae a leuk at $1 for aa chynges sin yer last visit.',

# Delete
'deletepage'            => 'Delete page',
'excontent'             => "content wis: '$1'",
'excontentauthor'       => "content wis: '$1' (an the ae contreibutor wis '[[Special:Contributions/$2|$2]]')",
'exbeforeblank'         => "content afore blankin wis: '$1'",
'exblank'               => 'page wis tuim',
'delete-confirm'        => 'Delete "$1"',
'delete-legend'         => 'Delete',
'historywarning'        => "Warnin: The page ye're aboot tae delete haes a history:",
'confirmdeletetext'     => "Ye'r aboot tae permanently delete a page or eimage alang wi aa its history frae the database.
Please confirm that ye intend tae dae this, that ye unnerstaun the consequences,
an that ye'r daein this in accord wi [[{{MediaWiki:Policy-url}}]].",
'actioncomplete'        => 'Action duin',
'actionfailed'          => 'Action failed',
'deletedtext'           => '"$1" haes been delete. See $2 for a record o recent deletions.',
'dellogpage'            => 'Deletion log',
'dellogpagetext'        => 'Ablo is a leet o the maist recent deletions.',
'deletionlog'           => 'deletion log',
'reverted'              => 'Revertit tae aulder reveision',
'deletecomment'         => 'Raeson:',
'deletereasonotherlist' => 'Ither raeson',

# Rollback
'rollback'       => 'Row back edits',
'rollback_short' => 'Rowback',
'rollbacklink'   => 'rowback',
'rollbackfailed' => 'Rowback failed',
'cantrollback'   => 'Canna revert edit; last contreibutor is the ae author o this page.',
'alreadyrolled'  => 'Canna rowback last edit o [[$1]] bi [[User:$2|$2]] ([[User talk:$2|Talk]]); some ither bodie haes editit or rowed back the page aareadies. Last edit wis bi [[User:$3|$3]] ([[User talk:$3|Talk]]).',
'editcomment'    => "The edit comment wis: \"''\$1''\".",
'revertpage'     => 'Revertit edit o [[Special:Contributions/$2|$2]] ([[User talk:$2|Talk]]), chynged back tae last version bi [[User:$1|$1]]',

# Protect
'protectlogpage'              => 'Fend log',
'protectlogtext'              => 'Ablo is a leet o page locks/unlocks. See the [[Special:ProtectedPages|protected pages list]] for the list of currently operational page protections.',
'protectedarticle'            => 'protectit "[[$1]]"',
'unprotectedarticle'          => 'unprotectit "[[$1]]"',
'protect-title'               => 'Protectin "$1"',
'prot_1movedto2'              => '[[$1]] flittit til [[$2]]',
'protectcomment'              => 'Raeson:',
'protectexpiry'               => 'Expires:',
'protect-text'                => "Ye can see an chynge the protection level here for the page '''$1'''.",
'protect-default'             => 'Allow aw uisers',
'protect-level-autoconfirmed' => 'Baur new and unregistered uisers',
'protect-level-sysop'         => 'Juist administrators',
'protect-othertime'           => 'Ither time:',
'protect-othertime-op'        => 'ither time',
'protect-expiry-options'      => '2 oor:2 hours,1 day:1 day,3 days:3 days,1 week:1 week,2 weeks:2 weeks,1 month:1 month,3 months:3 months,6 months:6 months,1 year:1 year,infinite:infinite',

# Restrictions (nouns)
'restriction-edit'   => 'Edit',
'restriction-move'   => 'Flit',
'restriction-create' => 'Mak',
'restriction-upload' => 'Uplaid',

# Undelete
'undelete'               => 'Restore delete page',
'undeletepage'           => 'View an restore delete pages',
'viewdeletedpage'        => 'View delete pages',
'undeletepagetext'       => 'The follaein pages haev bin deleted but are aye in the archive an
can be restored. The archive micht be redd oot noo an then.',
'undeletehistory'        => 'Gin ye restore the page, aa reveisions will be restored til the history.
Gin a neow page wi the same name haes bin created syne the deletion, the restored
reveisions will appear in the aulder history, an the current reveision o the live page winna be autaematically replaced.',
'undeletehistorynoadmin' => 'This airticle haes been delete. The raeson for deletion is
shawn in the summary ablo, alang wi parteeculars o the uisers that haed editit this page
afore it wis delete. The actual text o thir deletit reveisions is available tae admeenistrators juist.',
'undeletelink'           => 'view/restore',
'undeleteviewlink'       => 'view',
'undeletedrevisions'     => '{{PLURAL:$1|1 reveision|$1 reveisions}} restored',
'cannotundelete'         => 'Undelete didna wirk; some ither bodie micht hae aareadies undeletit the page.',

# Namespace form on various pages
'namespace'      => 'Namespace:',
'invert'         => 'Invert selection',
'blanknamespace' => '(Main)',

# Contributions
'contributions'       => 'Uiser contreibutions',
'contributions-title' => 'Uiser contreibutions fer $1',
'mycontris'           => 'Ma contreibutions',
'contribsub2'         => 'For $1 ($2)',
'nocontribs'          => 'Nae chynges wis funnd matchin thae criteria.',
'uctop'               => ' (tap)',
'month'               => 'Frae month (an afore):',
'year'                => 'Frae year (an afore):',

'sp-contributions-newbies'  => "Shaw contreibutions o' freish accounts ainlie",
'sp-contributions-blocklog' => 'block log',
'sp-contributions-uploads'  => 'uploads',
'sp-contributions-logs'     => 'logs',
'sp-contributions-talk'     => 'collogue',
'sp-contributions-search'   => 'Rake fur contreibutions',
'sp-contributions-username' => 'IP address or uisername:',
'sp-contributions-toponly'  => 'Ainlie shaw edits that are latest revisions',
'sp-contributions-submit'   => 'Rake',

# What links here
'whatlinkshere'            => 'Whit airts tae here',
'whatlinkshere-title'      => 'Pages that link to "$1"',
'whatlinkshere-page'       => 'Page:',
'linkshere'                => "The follaein pages airts tae '''[[:$1]]''':",
'nolinkshere'              => "Nae pages airt tae '''[[:$1]]'''.",
'isredirect'               => 'reguidal page',
'istemplate'               => 'transclusion',
'isimage'                  => 'file link',
'whatlinkshere-prev'       => '{{PLURAL:$1|previous|previous $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|next|next $1}}',
'whatlinkshere-links'      => '← links',
'whatlinkshere-hideredirs' => '$1 redirects',
'whatlinkshere-hidetrans'  => '$1 transclusions',
'whatlinkshere-hidelinks'  => '$1 links',
'whatlinkshere-hideimages' => '$1 image links',
'whatlinkshere-filters'    => 'Filters',

# Block/unblock
'blockip'                     => 'Block uiser',
'blockiptext'                 => 'Uise the form ablo tae block write access frae a specific IP address or uisername. This shuid be duin juist tae prevent vandalism, and in accord wi [[{{MediaWiki:Policy-url}}|policy]]. Fill in a specific raeson ablo (for exemplar, citin parteicular pages that wis damaged).',
'ipadressorusername'          => 'IP Address or uisername',
'ipbreason'                   => 'Raeson:',
'ipbsubmit'                   => 'Block this uiser',
'ipbother'                    => 'Ither time',
'ipboptions'                  => '2 hours:2 hours,1 day:1 day,3 days:3 days,1 week:1 week,2 weeks:2 weeks,1 month:1 month,3 months:3 months,6 months:6 months,1 year:1 year,indefinite:infinite',
'ipbotheroption'              => 'ither',
'badipaddress'                => 'That IP address is nae guid',
'blockipsuccesssub'           => 'Block succeedit',
'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] haes been blockit.
<br />See [[Special:BlockList|IP block leet]] tae review blocks.',
'ipb-unblock-addr'            => 'Unblock $1',
'unblockip'                   => 'Unblock uiser',
'unblockiptext'               => 'Uise the form ablo tae restore screivin richts
tae an afore-blockit IP address or uisername.',
'ipblocklist'                 => 'Blockit uisers',
'anononlyblock'               => 'anon. juist',
'createaccountblock'          => 'accoont-makkin blockit',
'blocklink'                   => 'block',
'unblocklink'                 => 'unblock',
'change-blocklink'            => 'chynge block',
'contribslink'                => 'contreibs',
'autoblocker'                 => 'Autaematically blockit syne yer IP address haes been uised recently bi "[[User:$1|$1]]". The raeson gien for $1\'s block is "\'\'$2\'\'"',
'blocklogpage'                => 'Block log',
'blocklogentry'               => 'blockit [[$1]] wi an expiry time o $2 $3',
'blocklogtext'                => 'This is a log o uiser blockin an unblockin actions. Autaematically blockit IP addresses isna leetit. See the [[Special:BlockList|IP block leet]] for the leet o bans and blocks on the gae the nou.',
'unblocklogentry'             => 'unblockit $1',
'block-log-flags-nocreate'    => 'accoont-makkin blockit',
'range_block_disabled'        => 'The administrator abeility tae mak range blocks is disabled.',
'proxyblockreason'            => 'Yer IP address haes been blockit sith it is an open proxy. Please contact yer Internet service provider or tech support an inform them o this serious security problem.',
'proxyblocksuccess'           => 'Duin',
'sorbsreason'                 => 'Yer IP address is leetit as an open proxy in the DNSBL.',
'sorbs_create_account_reason' => 'Yer IP address is leetit as an open proxy in the DNSBL. Ye canna mak an accoont',

# Developer tools
'unlockdb'            => 'Lowse database',
'lockdbtext'          => "Lockin the database will suspend the abeility o aa uisers tae edit pages, chynge thair preferences, edit thair watchleets, an ither things requirin chynges in the database. Please confirm that this is whit ye intend tae dae, an that ye'll unlock the database whan yer maintenance is duin.",
'unlockdbtext'        => 'Lowsin the database will gie back the abeility for aa uisers tae edit pages, chynge their preferences, edit their watchleets, an ither things needin chynges in the database. Please confirm that this is whit ye ettle tae dae.',
'lockconfirm'         => 'Aye, A raellie want tae lock the database.',
'unlockconfirm'       => 'Aye, A raelly want tae lowse the database.',
'locknoconfirm'       => 'Ye didna tick the confirmation box.',
'lockdbsuccesssub'    => 'Database lock fine',
'unlockdbsuccesssub'  => 'Database lowsed',
'lockdbsuccesstext'   => 'The database haes been lockit. <br />Mynd an tak the lock aff efter yer maintenance is feinisht.',
'unlockdbsuccesstext' => 'The database haes bin lowsed.',
'databasenotlocked'   => 'The database isna lockit.',

# Move page
'move-page-legend'        => 'Flit page',
'movepagetext'            => "Uisin the form ablo will rename a page, flittin aa its history tae the new name.
The auld teitle will become a reguidal page tae the new teitle.
Airtins tae the auld page teitle willna be chynged;
be siccar tae check for dooble or brucken reguidals.
You ar responsible for makkin siccar that airtins continues tae pynt whaur thay ar supposed tae gang.

Mynd that the page '''willna''' be flittit gin the'r aareadies a page at the new teitle, unless it is tuim or a reguidal and haes nae past edit history.
This means that ye can rename a page back tae whaur it wis juist renamed frae gin ye mak a mistak, an ye canna owerwrite an existin page

'''WARNIN!'''
This can be a drastic and unexpectit chynge for a popular page;
please be siccar ye unnerstaun the consequences o this afore proceedin.",
'movepagetalktext'        => "The associate Collogue page, gin onie, will be autaematically flittit alang wi it '''unless:''' *Ye'r flittin the page across namespaces, *A collogue page that isna tuim aareadies exists unner the new name, or *Ye tak the tick oot o the box ablo. In thae cases, ye maun flit or merge the page manually later gin ye hae saicont thochts.",
'movearticle'             => 'Flit page:',
'movenologin'             => 'No loggit in',
'movenologintext'         => 'Ye maun be a registert uiser an [[Special:UserLogin|loggit in]] tae flit a page.',
'newtitle'                => 'Tae new teitle',
'movepagebtn'             => 'Flit page',
'pagemovedsub'            => 'Flittin succeedit',
'articleexists'           => "A page o that name aareadies exists, or the name ye'v waled isna guid. Please wale anither name.",
'talkexists'              => 'The page itsel wis flittit fine, but the collogue page cuidna be flittit sith ane aareadies exists at the new teitle. Please merge thaim manually.',
'movedto'                 => 'flittit ti',
'movetalk'                => 'Flit "collogue" page an aa, gin it\'s applicable.',
'movelogpage'             => 'Flit log',
'movelogpagetext'         => "A leet o pages that's flitted is ablo.",
'movereason'              => 'Raeson:',
'revertmove'              => 'revert',
'delete_and_move'         => 'Delete an flit',
'delete_and_move_text'    => '==Deletion caad for==

The destination airticle "[[:$1]]" aareadies exists. Div ye want tae delete it for tae mak wey for the flittin?',
'delete_and_move_confirm' => 'Aye, delete the page',
'delete_and_move_reason'  => 'Delete for tae mak wey for flittin',
'selfmove'                => 'Ootgaun an incomin teitles is the same; canna flit a page ower itsel.',

# Export
'export'        => 'Export pages',
'exporttext'    => 'Ye can export the text an editin history o a parteicular page or set o pages wappit in some XML. In the futur, this micht can be importit intae anither wiki runnin MediaWiki saftware, altho the\'r nae support for this featur in the current version.

Tae export airticle pages, enter the teitles in the text box ablo, ae teitle tae ilka line, an wale whither ye want the current version alang wi aa auld versions, wi the page history lines, or the current version juist, wi wittins anent the last edit.

In the saicont case ye can uise an airtin forbye, for exemplar [[{{#Special:Export}}/{{MediaWiki:Mainpage}}]] for the airticle "[[{{MediaWiki:Mainpage}}]]".',
'exportcuronly' => 'Include juist the current revision, no the fou history',

# Namespace 8 related
'allmessages'               => 'Aa seestem messages',
'allmessagesname'           => 'Name',
'allmessagesdefault'        => 'Defaut text',
'allmessagescurrent'        => 'Text the nou',
'allmessagestext'           => 'This is a leet o aa seestem messages available in the MediaWiki: namespace.',
'allmessagesnotsupportedDB' => "'''{{ns:special}}:AllMessages''' nae supportit acause '''\$wgUseDatabaseMessages''' is aff.",

# Thumbnails
'thumbnail-more'  => 'Eik',
'filemissing'     => 'File missin',
'thumbnail_error' => 'Error creating thumbnail: $1',

# Special:Import
'importtext'            => 'Please export the file frae the soorce wiki uisin the Special:Export utility, hain it in yer disc an uplaid it here.',
'importnotext'          => 'Tuim or nae text',
'importsuccess'         => 'Importit fine!',
'importhistoryconflict' => 'Conflictin history revision exists (micht hae importit this page afore)',
'importnosources'       => 'Nae transwiki import soorces haes been defined an direct history uplaids is disabled.',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Yer uiser page',
'tooltip-pt-mytalk'               => 'Yer collogue page',
'tooltip-pt-preferences'          => 'Ma preferences',
'tooltip-pt-watchlist'            => "Th' leet o' pages yer monitoring fur changes",
'tooltip-pt-mycontris'            => 'Leet o yer contreibutions',
'tooltip-pt-login'                => "It's a guid idea tae log i, but ye dinna hae tae.",
'tooltip-pt-logout'               => 'Log oot',
'tooltip-ca-talk'                 => "Discussion aboot th' content page",
'tooltip-ca-edit'                 => "Ye kin edit this page. Please uise th' preview button afore saving",
'tooltip-ca-addsection'           => 'Start a new section',
'tooltip-ca-viewsource'           => 'This page is protectit.
You ken view its source',
'tooltip-ca-history'              => "Bygane revisions o' this page",
'tooltip-ca-protect'              => 'Fend this page',
'tooltip-ca-delete'               => 'Delete this page',
'tooltip-ca-move'                 => 'Flit this page',
'tooltip-ca-watch'                => 'Add this page tae yer watchleet',
'tooltip-ca-unwatch'              => 'Remove this page frum yer watchleet',
'tooltip-search'                  => 'Rake {{SITENAME}}',
'tooltip-search-go'               => "Gang tae a page wi' this exact name if exists",
'tooltip-search-fulltext'         => "Search th' pages fur this text",
'tooltip-p-logo'                  => 'Gang tae the Main Page',
'tooltip-n-mainpage'              => 'Gang tae the Main Page',
'tooltip-n-mainpage-description'  => 'Gang tae the Main Page',
'tooltip-n-portal'                => "Aboot th' project, whit ye kin dae, whaur tae fin' things",
'tooltip-n-currentevents'         => "Fin' background speirins oan current events",
'tooltip-n-recentchanges'         => 'The leet o recent chynges in the wiki',
'tooltip-n-randompage'            => 'Load a random page',
'tooltip-n-help'                  => "Th' steid tae fin' oot",
'tooltip-t-whatlinkshere'         => "List o' a' wiki pages that link 'ere",
'tooltip-t-recentchangeslinked'   => 'Recent changes in pages linked frae this page',
'tooltip-feed-atom'               => 'Atom feed fur this page',
'tooltip-t-contributions'         => "View this uiser's contreibutions",
'tooltip-t-emailuser'             => 'Send an e-mail to this uiser',
'tooltip-t-upload'                => 'Uplaid files',
'tooltip-t-specialpages'          => 'Leet o byordinar pages',
'tooltip-t-print'                 => "Printable version o' this page",
'tooltip-t-permalink'             => "Permanent link tae this revision o' th' page",
'tooltip-ca-nstab-main'           => 'Leuk at content page',
'tooltip-ca-nstab-user'           => 'View the uiser page',
'tooltip-ca-nstab-special'        => "This is a byordinar page, ye cannae edit th' page itself",
'tooltip-ca-nstab-project'        => 'View the project page',
'tooltip-ca-nstab-image'          => 'View the file page',
'tooltip-ca-nstab-template'       => 'View the template',
'tooltip-ca-nstab-category'       => "View th' category page",
'tooltip-minoredit'               => 'Mairk this as a smaa edit',
'tooltip-save'                    => 'Hain yer chynges',
'tooltip-preview'                 => 'Scance ower yer chynges, please uise this afore hainin!',
'tooltip-diff'                    => 'Shaw the chynges that you made tae the text.',
'tooltip-compareselectedversions' => 'See the differs atween the twa selectit versions o this page.',
'tooltip-watch'                   => 'Add this page tae yer watchleet',
'tooltip-rollback'                => '"Rowback" reverts edit(s) tae this page o\' th\' lest contributor in yin click',
'tooltip-undo'                    => "\"Undo\" reverts this edit 'n' opens th' edit form in preview mode. It allows adding a reason in th' summary.",
'tooltip-summary'                 => 'Enter a short summary',

# Metadata
'notacceptable' => 'The wiki server canna provide data in a format yer client can read.',

# Attribution
'anonymous'     => 'Nameless uiser(s) o {{SITENAME}}',
'siteuser'      => '{{SITENAME}} uiser $1',
'othercontribs' => 'Based on wark bi $1.',
'others'        => 'ithers',
'siteusers'     => '{{SITENAME}} uiser(s) $1',
'nocredits'     => "The'r nae credit info available for this page.",

# Spam protection
'spamprotectiontext'  => 'The page ye wanted tae save wis blockit bi the spam filter. This is maist likely caused bi an airtin til an outby site.',
'spamprotectionmatch' => 'The follaein text is whit triggered wir spam filter: $1',

# Patrolling
'markaspatrolleddiff'   => 'Merk as patrolled',
'markaspatrolledtext'   => 'Merk this airticle as patrolled',
'markedaspatrolled'     => 'Merkit as patrolled',
'markedaspatrolledtext' => 'The selectit reveision haes been merkit as patrolled.',
'rcpatroldisabledtext'  => 'The Recent Changes Patrol feature is disabled the nou.',

# Image deletion
'deletedrevision' => 'Deletit auld revision $1.',

# Browsing diffs
'previousdiff' => '← Aulder edit',
'nextdiff'     => 'Newer edit →',

# Media information
'mediawarning'   => "'''Warnin''': This file micht haud mislushious code; bi executin it yer seestem micht be compromised.",
'imagemaxsize'   => 'Limit eimages on eimage description pages tae:',
'file-info-size' => '$1 × $2 pixels, file size: $3, MIME type: $4',
'file-nohires'   => 'Na higher resolution available.',
'svg-long-desc'  => 'SVG file, nominally $1 × $2 pixels, file size: $3',
'show-big-image' => 'Full resolution',

# Special:NewFiles
'newimages'     => 'Gallery o new files',
'imagelisttext' => 'Ablo is a leet o $1 {{PLURAL:$1|eimage|eimages}} sortit $2.',
'noimages'      => 'Naething tae see.',
'ilsubmit'      => 'Rake',
'bydate'        => 'bi date',

# Bad image list
'bad_image_list' => "Th' format is as follows:

Ainlie list items (lines starting wi' *) are considered. Th' foremaist link oan a line mist be a link tae a ill image. Ony subsequent links oan th' same line are considered tae be exceptions, i,e., pages whaur th' image kin occur inline.",

# Metadata
'metadata'        => 'Metadata',
'metadata-help'   => "This file contains additional speirins, likelie added frae th' digital camera or scanner used tae create or digitize it. 
If th' file haes bin modified frae tis original state, some details kin nae fully reflect th' modified file.",
'metadata-fields' => "Image metadata fields listed in this message wull be included oan image page display whin th' metadata buird is collapsed. Others wull be hidden by default. 
*mak
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyricht
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude",

# EXIF tags
'exif-copyright'               => 'Copyricht hauder',
'exif-colorspace'              => 'Colour space',
'exif-componentsconfiguration' => 'Meanin o ilka component',
'exif-compressedbitsperpixel'  => 'Eimage compression mode',
'exif-brightnessvalue'         => 'Brichtness',

'exif-componentsconfiguration-0' => 'disna exist',

'exif-gaincontrol-0' => 'Nane',

'exif-contrast-1' => 'Saft',

# External editor support
'edit-externally'      => 'Edit this file uisin an external application',
'edit-externally-help' => '(See the [https://www.mediawiki.org/wiki/Manual:External_editors setup instructions] for mair guidance.)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'aw',
'namespacesall' => 'aa',
'monthsall'     => 'aw',
'limitall'      => 'aw',

# Email address confirmation
'confirmemail_noemail'    => 'Ye dinna hae a valid email address set in yer [[Special:Preferences|uiser preferences]].',
'confirmemail_text'       => 'This wiki requires ye tae validate yer e-mail address
afore uisin e-mail featurs. Activate the button ablo tae send a confirmation
mail tae yer address. The mail will include an airtin containing a code; laid the
airtin in yer brouser tae confirm that yer e-mail address is guid.',
'confirmemail_sendfailed' => 'Cuidna send confirmation mail. Hae a leuk at the address for invalid characters.

Mailer returned: $1',
'confirmemail_invalid'    => 'Confirmation code nae guid. The code haes mibbe expired.',
'confirmemail_needlogin'  => 'Ye maun $1 for tae confirm yer email address.',
'confirmemail_success'    => 'Yer e-mail address haes been confirmed. Ye can nou log in an enjoy the wiki.',
'confirmemail_loggedin'   => 'Yer e-mail address haes noo been confirmed.',
'confirmemail_error'      => 'Something gaed agley hainin yer confirmation.',
'confirmemail_body'       => 'A bodie, maist likely you frae IP address $1, haes registert an
accoont "$2" wi this e-mail address on {{SITENAME}}.

Tae confirm that you ar aucht this accoont an activate e-mail featurs
on {{SITENAME}}, open this airtin in yer brouser:

$3

If this *isna* you, dinna follae the airtin.

$5

This confirmation code will end at $4.',

# Delete conflict
'deletedwhileediting' => 'Warnin: This page haes been delete syne ye stertit editin!',
'confirmrecreate'     => "Uiser [[User:$1|$1]] ([[User talk:$1|collogue]]) deletit this airticle efter ye stertit editin, giein the raeson:
: ''$2''
Please confirm that ye really want tae recreate this airticle.",

# action=purge
'confirm_purge_button' => 'Aye',
'confirm-purge-top'    => 'Clair the cache o this page?',

# Multipage image navigation
'imgmultigo' => 'Gang!',

# Table pager
'table_pager_next'         => 'Page aifter',
'table_pager_prev'         => 'Page afore',
'table_pager_limit_submit' => 'Gang',
'table_pager_empty'        => 'Nae results',

# Auto-summaries
'autosumm-blank'   => 'Dichtin aa content frae page',
'autosumm-replace' => "Replacin page wi '$1'",
'autoredircomment' => 'Reguidin tae [[$1]]',

# Watchlist editing tools
'watchlisttools-view' => 'View relevant changes',
'watchlisttools-edit' => 'View an edit watchleet',
'watchlisttools-raw'  => 'Edit raw watchleet',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'Wairnin:\'\'\' Default sort key "$2" overrides earlier default sort key "$1".',

# Special:FilePath
'filepath-page' => 'File:',

# Special:FileDuplicateSearch
'fileduplicatesearch-filename' => 'Filename:',
'fileduplicatesearch-submit'   => 'Rake',

# Special:SpecialPages
'specialpages'             => 'Byordinar pages',
'specialpages-group-users' => 'Uisers an richts',
'specialpages-group-pages' => 'leet o pages',

# External image whitelist
'external_image_whitelist' => ' #Leave this line exactly as it is<pre>
#Put regular expression fragments (just the part that goes between the //) below
#These will be matched with the URLs of external (hotlinked) images
#Those that match will be displayed as images, otherwise only a link to the image will be shown
#Lines beginning with # are treated as comments
#This is case-insensitive

#Put all regex fragments above this line. Leave this line exactly as it is</pre>',

# Special:Tags
'tag-filter'        => '[[Special:Tags|Tag]] filter:',
'tag-filter-submit' => 'Filter',
'tags-edit'         => 'edit',

# HTML forms
'htmlform-selectorother-other' => 'Ither',

);
